Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Parser ¶
type Parser struct {
// contains filtered or unexported fields
}
Parser implements a simple text parser
func (*Parser) ParseWithCallback ¶ added in v0.6.0
func (p *Parser) ParseWithCallback(ctx context.Context, r io.Reader, callback func(core.Chunk) error) error
ParseWithCallback parses text and calls the callback for each chunk
func (*Parser) SupportedFormats ¶
SupportedFormats returns supported formats
type SemanticParser ¶ added in v0.6.0
type SemanticParser struct {
// contains filtered or unexported fields
}
SemanticParser implements semantic chunking based on sentence boundaries and semantic similarity
func NewSemanticParser ¶ added in v0.6.0
func NewSemanticParser(embedder embedding.Provider) *SemanticParser
NewSemanticParser creates a new semantic parser
func (*SemanticParser) Parse ¶ added in v0.6.0
Parse parses text into semantically meaningful chunks
func (*SemanticParser) SupportedFormats ¶ added in v0.6.0
func (p *SemanticParser) SupportedFormats() []string
SupportedFormats returns supported formats
type StreamingParser ¶ added in v0.6.0
type StreamingParser struct {
// contains filtered or unexported fields
}
func NewStreamingParser ¶ added in v0.6.0
func NewStreamingParser() *StreamingParser
NewStreamingParser creates a new streaming text parser
func (*StreamingParser) Parse ¶ added in v0.6.0
Parse parses text into chunks using streaming processing
func (*StreamingParser) SupportedFormats ¶ added in v0.6.0
func (p *StreamingParser) SupportedFormats() []string
SupportedFormats returns supported formats
Click to show internal directories.
Click to hide internal directories.